@@ -21,6 +21,7 @@ func (e *Exporter) configureOptions(uri string) ([]redis.DialOption, error) {
 		redis.DialReadTimeout(e.options.ConnectionTimeouts),
 		redis.DialWriteTimeout(e.options.ConnectionTimeouts),
 		redis.DialTLSConfig(tlsConfig),
+		redis.DialUseTLS(strings.HasPrefix(e.redisAddr, "rediss://")),
 	}
 
 	if e.options.User != "" {
@@ -66,6 +67,16 @@ func (e *Exporter) connectToRedis() (redis.Conn, error) {
 
 func (e *Exporter) connectToRedisCluster() (redis.Conn, error) {
 	uri := e.redisAddr
+	if !strings.Contains(uri, "://") {
+		uri = "redis://" + uri
+	}
+
+	options, err := e.configureOptions(uri)
+	if err != nil {
+		return nil, err
+	}
+
+	// remove url scheme for redis.Cluster.StartupNodes
 	if strings.Contains(uri, "://") {
 		u, _ := url.Parse(uri)
 		if u.Port() == "" {
@@ -79,11 +90,6 @@ func (e *Exporter) connectToRedisCluster() (redis.Conn, error) {
 		}
 	}
 
-	options, err := e.configureOptions(uri)
-	if err != nil {
-		return nil, err
-	}
-
 	log.Debugf("Creating cluster object")
 	cluster := redisc.Cluster{
 		StartupNodes: []string{uri},
@@ -109,7 +115,7 @@ func (e *Exporter) connectToRedisCluster() (redis.Conn, error) {
 }
 
 func doRedisCmd(c redis.Conn, cmd string, args ...interface{}) (interface{}, error) {
-	log.Debugf("c.Do() - running command: %s %s", cmd, args)
+	log.Debugf("c.Do() - running command: %s args: [%v]", cmd, args)
 	res, err := c.Do(cmd, args...)
 	if err != nil {
 		log.Debugf("c.Do() - err: %s", err)
