@@ -4,7 +4,7 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"fmt"
-	"io/ioutil"
+	"os"
 
 	log "github.com/sirupsen/logrus"
 )
@@ -29,6 +29,14 @@ func (e *Exporter) CreateClientTLSConfig() (*tls.Config, error) {
 			return nil, err
 		}
 		tlsConfig.RootCAs = certificates
+	} else {
+		// Load the system certificate pool
+		rootCAs, err := x509.SystemCertPool()
+		if err != nil {
+			return nil, err
+		}
+
+		tlsConfig.RootCAs = rootCAs
 	}
 
 	return &tlsConfig, nil
@@ -111,7 +119,7 @@ func LoadKeyPair(certFile, keyFile string) (*tls.Certificate, error) {
 // The file must contain PEM encoded data.
 func LoadCAFile(caFile string) (*x509.CertPool, error) {
 	log.Debugf("Load CA cert file: %s", caFile)
-	pemCerts, err := ioutil.ReadFile(caFile)
+	pemCerts, err := os.ReadFile(caFile)
 	if err != nil {
 		return nil, err
 	}
